@@ -669,14 +669,9 @@ namespace snapper
 
 #if 1
 	if (snapper->subvolumeDir() == "/" && snapper->getFilesystem()->fstype() == "btrfs" &&
-	    snapshot.getType() == PRE && access("/usr/lib/snapper/plugins/grub.py", X_OK) == 0)
+	    access("/usr/lib/snapper/plugins/grub", X_OK) == 0)
 	{
-	    map<string, string> userdata = snapshot.getUserdata();
-	    map<string, string>::const_iterator it = userdata.find("important");
-	    bool important = it != userdata.end() && it->second == "yes";
-
-	    SystemCmd cmd(sformat("/usr/lib/snapper/plugins/grub.py %d %s", snapshot.getNum(),
-				  important ? "yes" : "no"));
+	    SystemCmd cmd("/usr/lib/snapper/plugins/grub --refresh");
 	}
 #endif
 
@@ -705,6 +700,14 @@ namespace snapper
 	snapshot->userdata = userdata;
 
 	snapshot->writeInfo();
+
+#if 1
+	if (snapper->subvolumeDir() == "/" && snapper->getFilesystem()->fstype() == "btrfs" &&
+	    access("/usr/lib/snapper/plugins/grub", X_OK) == 0)
+	{
+	    SystemCmd cmd("/usr/lib/snapper/plugins/grub --refresh");
+	}
+#endif
     }
 
 
@@ -739,6 +742,14 @@ namespace snapper
 	infos_dir.unlink(decString(snapshot->getNum()), AT_REMOVEDIR);
 
 	entries.erase(snapshot);
+
+#if 1
+	if (snapper->subvolumeDir() == "/" && snapper->getFilesystem()->fstype() == "btrfs" &&
+	    access("/usr/lib/snapper/plugins/grub", X_OK) == 0)
+	{
+	    SystemCmd cmd("/usr/lib/snapper/plugins/grub --refresh");
+	}
+#endif
     }
 
 
